<?php

namespace Litecms\Notice\Actions;

use Illuminate\Support\Carbon;
use Illuminate\Support\Str;
use Litepie\Actions\Concerns\AsAction;
use Litepie\Actions\Traits\LogsActions;
use Litepie\Notification\Traits\SendNotification;
use Litecms\Notice\Models\Notice;


class NoticeAction
{
    use AsAction;
    use LogsActions;
    use SendNotification;

    private $model;

    public function handle(string $action, Notice $notice, array $request = [])
    {
        $this->model = $notice;

        $function = Str::camel($action);
        event('litecms.notice.notice.action.' . $action . 'ing', [$notice]);
        $data =  $this->$function($notice, $request);
        event('litecms.notice.notice.action.' . $action . 'ed', [$notice]);

        $this->logsAction();
        $this->notify();
        return $data;
    }


    public function store(Notice $notice, array $request)
    {
        $attributes = $request;
        $attributes['user_id'] = user_id();
        $attributes['user_type'] = user_type();
        $notice = $notice->create($attributes);
        return $notice;
    }

    public function update(Notice $notice, array $request)
    {
        $attributes = $request;
        $notice->update($attributes);
        return $notice;
    }

    public function destroy(Notice $notice, array $request)
    {
        $notice->delete();
        return $notice;
    }

    public function copy(Notice $notice, array $request)
    {
        $count = $request['count'] ?: 1;

        if ($count == 1) {
            $notice = $notice->replicate();
            $notice->created_at = Carbon::now();
            $notice->save();
            return $notice;
        }

        for ($i = 1; $i <= $count; $i++) {
            $new = $notice->replicate();
            $new->created_at = Carbon::now();
            $new->save();
        }

        return $notice;
    }


}
