<?php

namespace Litecms\Notice\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Notice\Actions\NoticeAction;
use Litecms\Notice\Http\Requests\NoticeActionRequest;
use Litecms\Notice\Http\Resources\NoticeResource;
use Litecms\Notice\Models\Notice;

/**
 * Admin web controller class.
 */
class NoticeActionController extends BaseController
{

    /**
     * Action controller function for notice.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(NoticeActionRequest $request, Notice $notice, $action)
    {
        try {
            $request = $request->all();
            $notice = NoticeAction::run($action, $notice, $request);

            $data = new NoticeResource($notice);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('notice::notice.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('notice/notice/' . $notice->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('notice/notice/' . $notice->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
