<?php

namespace Litecms\Notice\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Litecms\Notice\Http\Requests\NoticeActionsRequest;
use Litecms\Notice\Models\NoticeActions;

/**
 * Admin web controller class.
 */
class NoticeActionsController extends BaseController
{

    /**
     * Action controller function for notice.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(NoticeActionsRequest $request, $action)
    {
        try {
            $notice = NoticeActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('notice::notice.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('notice/notice/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('notice/notice/' . $action))
                ->redirect();
        }
    }
}
