<?php

namespace Litecms\Notice\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Notice\Events\NoticeAction as NoticeActionEvent;
use Litecms\Notice\Notifications\NoticeAction as NoticeActionNotification;
use Litepie\Actions\Concerns\AsAction;

class NoticeAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the NoticeActionEvent.
     *
     * @param   NoticeActionEvent  $event
     * @return mixed
     */
    public function handle(NoticeActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $notice.
     *
     * @param   NoticeActionEvent  $event
     * @return void
     */
    public function create(NoticeActionEvent $event)
    {
        $client = $event->$notice->client;
        Notification::send($client, new NoticeActionNotification($event));
    }

    /**
     * Handle the NoticeActionEvent as a listener.
     *
     * @param   NoticeActionEvent  $event
     * @return mixed
     */
    public function asListener(NoticeActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   NoticeActionEvent  $event
     * @return bool
     */
    private function isAllowed(NoticeActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
