<?php
namespace Litecms\Notice\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litecms\Notice\Events\NoticeAction as NoticeActionEvent;
use Litecms\Notice\Models\Notice;

class NoticeAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $notice;

    protected $action;

    /**
     * Create a new notification instance.
     *
     * @param NoticeActionEvent $notice
     * @param string $action
     */
    public function __construct(NoticeActionEvent $notice, string $action)
    {
        $this->action = $action;
        $this->notice = $notice;
    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Notice Approved - ' . config('app.name'))
            ->view('notice::notice.email.action', ['data' => $this->notice]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
