<?php

namespace Litecms\Notice\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Notice\Models\Notice;

class NoticePolicy
{

    use NoticeAction;

    /**
     * Determine if the given user can view the notice.
     *
     * @param UserPolicyInterface $authUser
     * @param Notice $notice
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Notice $notice)
    {
        if ($authUser->canDo('notice.notice.view') && $authUser->isAdmin()) {
            return true;
        }

        return $notice->user_id == user_id() && $notice->user_type == user_type();
    }

    /**
     * Determine if the given user can create a notice.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('notice.notice.create');
    }

    /**
     * Determine if the given user can update the given notice.
     *
     * @param UserPolicyInterface $authUser
     * @param Notice $notice
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Notice $notice)
    {
        if ($authUser->canDo('notice.notice.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $notice->user_id == user_id() && $notice->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given notice.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Notice $notice)
    {
        return $notice->user_id == user_id() && $notice->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given notice.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Notice $notice)
    {
        if ($authUser->canDo('notice.notice.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given notice.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Notice $notice)
    {
        if ($authUser->canDo('notice.notice.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
